===================================
``psyclone.psyir.frontend.fortran``
===================================

.. automodule:: psyclone.psyir.frontend.fortran

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.frontend.fortran


Classes
=======

- :py:class:`FortranReader`:
  PSyIR Fortran frontend. This frontend translates Fortran from a string


.. autoclass:: FortranReader
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: FortranReader
      :parts: 1
